@@ -21,13 +21,13 @@ from datetime import datetime, timedelta
 
 import pytz
 import requests
-from six.moves import urllib
+import urllib
 
 import faculty.config
 from faculty.session.accesstoken import AccessToken, AccessTokenMemoryCache
 
 
-class Session(object):
+class Session:
     """A session for connecting to Faculty services.
 
     This session encapsultates the configuration (address and authentication
